### CODIGO FACILITO

Este paquete nos permite consumir el API de la plataforma.

Es una copia del taller para crear paquetes de la página codigofacilito.com.

Hice este proyecto con el fin de aprender solamente.